#[non_exhaustive]pub struct GetTableMetadataInput {
pub catalog_name: Option<String>,
pub database_name: Option<String>,
pub table_name: Option<String>,
pub work_group: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.catalog_name: Option<String>The name of the data catalog that contains the database and table metadata to return.
database_name: Option<String>The name of the database that contains the table metadata to return.
table_name: Option<String>The name of the table for which metadata is returned.
work_group: Option<String>The name of the workgroup for which the metadata is being fetched. Required if requesting an IAM Identity Center enabled Glue Data Catalog.
Implementations
Sourceimpl GetTableMetadataInput
impl GetTableMetadataInput
Sourcepub fn catalog_name(&self) -> Option<&str>
pub fn catalog_name(&self) -> Option<&str>
The name of the data catalog that contains the database and table metadata to return.
Sourcepub fn database_name(&self) -> Option<&str>
pub fn database_name(&self) -> Option<&str>
The name of the database that contains the table metadata to return.
Sourcepub fn table_name(&self) -> Option<&str>
pub fn table_name(&self) -> Option<&str>
The name of the table for which metadata is returned.
Sourcepub fn work_group(&self) -> Option<&str>
pub fn work_group(&self) -> Option<&str>
The name of the workgroup for which the metadata is being fetched. Required if requesting an IAM Identity Center enabled Glue Data Catalog.
Sourceimpl GetTableMetadataInput
impl GetTableMetadataInput
Sourcepub fn builder() -> GetTableMetadataInputBuilder
pub fn builder() -> GetTableMetadataInputBuilder
Creates a new builder-style object to manufacture GetTableMetadataInput.